@@ -1,18 +1,20 @@
 """Photo service."""
-import json
 import base64
-from six import PY2
+import json
+from datetime import datetime
 
 # fmt: off
-from six.moves.urllib.parse import urlencode  # pylint: disable=bad-option-value,relative-import
+from urllib.parse import urlencode  # pylint: disable=bad-option-value,relative-import
+
+from pytz import UTC
+from six import PY2
+
+from icloudpy.exceptions import ICloudPyServiceNotActivatedException
+
 # fmt: on
 
-from datetime import datetime
-from icloudpy.exceptions import ICloudPyServiceNotActivatedException
-from pytz import UTC
 
-
-class PhotosService(object):
+class PhotosService:
     """The 'Photos' iCloud service."""
 
     SMART_FOLDERS = {
@@ -131,15 +133,14 @@ class PhotosService(object):
         self.params = dict(params)
         self._service_root = service_root
         self.service_endpoint = (
-            "%s/database/1/com.apple.photos.cloud/production/private"
-            % self._service_root
+            f"{self._service_root}/database/1/com.apple.photos.cloud/production/private"
         )
 
         self._albums = None
 
         self.params.update({"remapEnums": True, "getCurrentSyncToken": True})
 
-        url = "%s/records/query?%s" % (self.service_endpoint, urlencode(self.params))
+        url = f"{self.service_endpoint}/records/query?{urlencode(self.params)}"
         json_data = (
             '{"query":{"recordType":"CheckIndexingState"},'
             '"zoneID":{"zoneName":"PrimarySync"}}'
@@ -173,7 +174,7 @@ class PhotosService(object):
 
             for folder in self._fetch_folders():
 
-                # Skiping albums having null name, that can happen sometime
+                # Skipping albums having null name, that can happen sometime
                 if "albumNameEnc" not in folder["fields"]:
                     continue
 
@@ -185,7 +186,7 @@ class PhotosService(object):
 
                 folder_id = folder["recordName"]
                 folder_obj_type = (
-                    "CPLContainerRelationNotDeletedByAssetDate:%s" % folder_id
+                    f"CPLContainerRelationNotDeletedByAssetDate:{folder_id}"
                 )
                 folder_name = base64.b64decode(
                     folder["fields"]["albumNameEnc"]["value"]
@@ -212,7 +213,7 @@ class PhotosService(object):
         return self._albums
 
     def _fetch_folders(self):
-        url = "%s/records/query?%s" % (self.service_endpoint, urlencode(self.params))
+        url = f"{self.service_endpoint}/records/query?{urlencode(self.params)}"
         json_data = (
             '{"query":{"recordType":"CPLAlbumByPositionLive"},'
             '"zoneID":{"zoneName":"PrimarySync"}}'
@@ -231,7 +232,7 @@ class PhotosService(object):
         return self.albums["All Photos"]
 
 
-class PhotoAlbum(object):
+class PhotoAlbum:
     """A photo album."""
 
     def __init__(
@@ -243,7 +244,7 @@ class PhotoAlbum(object):
         direction,
         query_filter=None,
         page_size=100,
-        folder_id=None
+        folder_id=None,
     ):
         self.name = name
         self.service = service
@@ -268,30 +269,27 @@ class PhotoAlbum(object):
 
     def __len__(self):
         if self._len is None:
-            url = "%s/internal/records/query/batch?%s" % (
-                self.service.service_endpoint,
-                urlencode(self.service.params),
-            )
+            url = f"{self.service.service_endpoint}/internal/records/query/batch?{urlencode(self.service.params)}"
             request = self.service.session.post(
                 url,
                 data=json.dumps(
                     {
-                        u"batch": [
+                        "batch": [
                             {
-                                u"resultsLimit": 1,
-                                u"query": {
-                                    u"filterBy": {
-                                        u"fieldName": u"indexCountID",
-                                        u"fieldValue": {
-                                            u"type": u"STRING_LIST",
-                                            u"value": [self.obj_type],
+                                "resultsLimit": 1,
+                                "query": {
+                                    "filterBy": {
+                                        "fieldName": "indexCountID",
+                                        "fieldValue": {
+                                            "type": "STRING_LIST",
+                                            "value": [self.obj_type],
                                         },
-                                        u"comparator": u"IN",
+                                        "comparator": "IN",
                                     },
-                                    u"recordType": u"HyperionIndexCountLookup",
+                                    "recordType": "HyperionIndexCountLookup",
                                 },
-                                u"zoneWide": True,
-                                u"zoneID": {u"zoneName": u"PrimarySync"},
+                                "zoneWide": True,
+                                "zoneID": {"zoneName": "PrimarySync"},
                             }
                         ]
                     }
@@ -307,10 +305,11 @@ class PhotoAlbum(object):
         return self._len
 
     def _fetch_subalbums(self):
-        url = ("%s/records/query?" % self.service.service_endpoint) + urlencode(
+        url = (f"{self.service.service_endpoint}/records/query?") + urlencode(
             self.service.params
         )
-        query = '''{{
+        # pylint: disable=consider-using-f-string
+        query = """{{
                 "query": {{
                     "recordType":"CPLAlbumByPositionLive",
                     "filterBy": [
@@ -327,10 +326,10 @@ class PhotoAlbum(object):
                 "zoneID": {{
                     "zoneName":"PrimarySync"
                 }}
-            }}'''.format(self.folder_id)
-        json_data = (
-            query
+            }}""".format(
+            self.folder_id
         )
+        json_data = query
         request = self.service.session.post(
             url,
             data=json_data,
@@ -345,13 +344,15 @@ class PhotoAlbum(object):
         """Returns the subalbums"""
         if not self._subalbums and self.folder_id:
             for folder in self._fetch_subalbums():
-                if (folder["fields"].get("isDeleted")
-                    and folder["fields"]["isDeleted"]["value"]):
+                if (
+                    folder["fields"].get("isDeleted")
+                    and folder["fields"]["isDeleted"]["value"]
+                ):
                     continue
 
                 folder_id = folder["recordName"]
                 folder_obj_type = (
-                    "CPLContainerRelationNotDeletedByAssetDate:%s" % folder_id
+                    f"CPLContainerRelationNotDeletedByAssetDate:{folder_id}"
                 )
                 folder_name = base64.b64decode(
                     folder["fields"]["albumNameEnc"]["value"]
@@ -385,7 +386,7 @@ class PhotoAlbum(object):
             offset = 0
 
         while True:
-            url = ("%s/records/query?" % self.service.service_endpoint) + urlencode(
+            url = (f"{self.service.service_endpoint}/records/query?") + urlencode(
                 self.service.params
             )
             request = self.service.session.post(
@@ -425,122 +426,122 @@ class PhotoAlbum(object):
 
     def _list_query_gen(self, offset, list_type, direction, query_filter=None):
         query = {
-            u"query": {
-                u"filterBy": [
+            "query": {
+                "filterBy": [
                     {
-                        u"fieldName": u"startRank",
-                        u"fieldValue": {u"type": u"INT64", u"value": offset},
-                        u"comparator": u"EQUALS",
+                        "fieldName": "startRank",
+                        "fieldValue": {"type": "INT64", "value": offset},
+                        "comparator": "EQUALS",
                     },
                     {
-                        u"fieldName": u"direction",
-                        u"fieldValue": {u"type": u"STRING", u"value": direction},
-                        u"comparator": u"EQUALS",
+                        "fieldName": "direction",
+                        "fieldValue": {"type": "STRING", "value": direction},
+                        "comparator": "EQUALS",
                     },
                 ],
-                u"recordType": list_type,
+                "recordType": list_type,
             },
-            u"resultsLimit": self.page_size * 2,
-            u"desiredKeys": [
-                u"resJPEGFullWidth",
-                u"resJPEGFullHeight",
-                u"resJPEGFullFileType",
-                u"resJPEGFullFingerprint",
-                u"resJPEGFullRes",
-                u"resJPEGLargeWidth",
-                u"resJPEGLargeHeight",
-                u"resJPEGLargeFileType",
-                u"resJPEGLargeFingerprint",
-                u"resJPEGLargeRes",
-                u"resJPEGMedWidth",
-                u"resJPEGMedHeight",
-                u"resJPEGMedFileType",
-                u"resJPEGMedFingerprint",
-                u"resJPEGMedRes",
-                u"resJPEGThumbWidth",
-                u"resJPEGThumbHeight",
-                u"resJPEGThumbFileType",
-                u"resJPEGThumbFingerprint",
-                u"resJPEGThumbRes",
-                u"resVidFullWidth",
-                u"resVidFullHeight",
-                u"resVidFullFileType",
-                u"resVidFullFingerprint",
-                u"resVidFullRes",
-                u"resVidMedWidth",
-                u"resVidMedHeight",
-                u"resVidMedFileType",
-                u"resVidMedFingerprint",
-                u"resVidMedRes",
-                u"resVidSmallWidth",
-                u"resVidSmallHeight",
-                u"resVidSmallFileType",
-                u"resVidSmallFingerprint",
-                u"resVidSmallRes",
-                u"resSidecarWidth",
-                u"resSidecarHeight",
-                u"resSidecarFileType",
-                u"resSidecarFingerprint",
-                u"resSidecarRes",
-                u"itemType",
-                u"dataClassType",
-                u"filenameEnc",
-                u"originalOrientation",
-                u"resOriginalWidth",
-                u"resOriginalHeight",
-                u"resOriginalFileType",
-                u"resOriginalFingerprint",
-                u"resOriginalRes",
-                u"resOriginalAltWidth",
-                u"resOriginalAltHeight",
-                u"resOriginalAltFileType",
-                u"resOriginalAltFingerprint",
-                u"resOriginalAltRes",
-                u"resOriginalVidComplWidth",
-                u"resOriginalVidComplHeight",
-                u"resOriginalVidComplFileType",
-                u"resOriginalVidComplFingerprint",
-                u"resOriginalVidComplRes",
-                u"isDeleted",
-                u"isExpunged",
-                u"dateExpunged",
-                u"remappedRef",
-                u"recordName",
-                u"recordType",
-                u"recordChangeTag",
-                u"masterRef",
-                u"adjustmentRenderType",
-                u"assetDate",
-                u"addedDate",
-                u"isFavorite",
-                u"isHidden",
-                u"orientation",
-                u"duration",
-                u"assetSubtype",
-                u"assetSubtypeV2",
-                u"assetHDRType",
-                u"burstFlags",
-                u"burstFlagsExt",
-                u"burstId",
-                u"captionEnc",
-                u"locationEnc",
-                u"locationV2Enc",
-                u"locationLatitude",
-                u"locationLongitude",
-                u"adjustmentType",
-                u"timeZoneOffset",
-                u"vidComplDurValue",
-                u"vidComplDurScale",
-                u"vidComplDispValue",
-                u"vidComplDispScale",
-                u"vidComplVisibilityState",
-                u"customRenderedValue",
-                u"containerId",
-                u"itemId",
-                u"position",
-                u"isKeyAsset",
+            "resultsLimit": self.page_size * 2,
+            "desiredKeys": [
+                "resJPEGFullWidth",
+                "resJPEGFullHeight",
+                "resJPEGFullFileType",
+                "resJPEGFullFingerprint",
+                "resJPEGFullRes",
+                "resJPEGLargeWidth",
+                "resJPEGLargeHeight",
+                "resJPEGLargeFileType",
+                "resJPEGLargeFingerprint",
+                "resJPEGLargeRes",
+                "resJPEGMedWidth",
+                "resJPEGMedHeight",
+                "resJPEGMedFileType",
+                "resJPEGMedFingerprint",
+                "resJPEGMedRes",
+                "resJPEGThumbWidth",
+                "resJPEGThumbHeight",
+                "resJPEGThumbFileType",
+                "resJPEGThumbFingerprint",
+                "resJPEGThumbRes",
+                "resVidFullWidth",
+                "resVidFullHeight",
+                "resVidFullFileType",
+                "resVidFullFingerprint",
+                "resVidFullRes",
+                "resVidMedWidth",
+                "resVidMedHeight",
+                "resVidMedFileType",
+                "resVidMedFingerprint",
+                "resVidMedRes",
+                "resVidSmallWidth",
+                "resVidSmallHeight",
+                "resVidSmallFileType",
+                "resVidSmallFingerprint",
+                "resVidSmallRes",
+                "resSidecarWidth",
+                "resSidecarHeight",
+                "resSidecarFileType",
+                "resSidecarFingerprint",
+                "resSidecarRes",
+                "itemType",
+                "dataClassType",
+                "filenameEnc",
+                "originalOrientation",
+                "resOriginalWidth",
+                "resOriginalHeight",
+                "resOriginalFileType",
+                "resOriginalFingerprint",
+                "resOriginalRes",
+                "resOriginalAltWidth",
+                "resOriginalAltHeight",
+                "resOriginalAltFileType",
+                "resOriginalAltFingerprint",
+                "resOriginalAltRes",
+                "resOriginalVidComplWidth",
+                "resOriginalVidComplHeight",
+                "resOriginalVidComplFileType",
+                "resOriginalVidComplFingerprint",
+                "resOriginalVidComplRes",
+                "isDeleted",
+                "isExpunged",
+                "dateExpunged",
+                "remappedRef",
+                "recordName",
+                "recordType",
+                "recordChangeTag",
+                "masterRef",
+                "adjustmentRenderType",
+                "assetDate",
+                "addedDate",
+                "isFavorite",
+                "isHidden",
+                "orientation",
+                "duration",
+                "assetSubtype",
+                "assetSubtypeV2",
+                "assetHDRType",
+                "burstFlags",
+                "burstFlagsExt",
+                "burstId",
+                "captionEnc",
+                "locationEnc",
+                "locationV2Enc",
+                "locationLatitude",
+                "locationLongitude",
+                "adjustmentType",
+                "timeZoneOffset",
+                "vidComplDurValue",
+                "vidComplDurScale",
+                "vidComplDispValue",
+                "vidComplDispScale",
+                "vidComplVisibilityState",
+                "customRenderedValue",
+                "containerId",
+                "itemId",
+                "position",
+                "isKeyAsset",
             ],
-            u"zoneID": {u"zoneName": u"PrimarySync"},
+            "zoneID": {"zoneName": "PrimarySync"},
         }
 
         if query_filter:
@@ -558,10 +559,10 @@ class PhotoAlbum(object):
         return as_unicode
 
     def __repr__(self):
-        return "<%s: '%s'>" % (type(self).__name__, self)
+        return f"<{type(self).__name__}: '{self}'>"
 
 
-class PhotoAsset(object):
+class PhotoAsset:
     """A photo."""
 
     def __init__(self, service, master_record, asset_record):
@@ -572,15 +573,15 @@ class PhotoAsset(object):
         self._versions = None
 
     PHOTO_VERSION_LOOKUP = {
-        u"original": u"resOriginal",
-        u"medium": u"resJPEGMed",
-        u"thumb": u"resJPEGThumb",
+        "original": "resOriginal",
+        "medium": "resJPEGMed",
+        "thumb": "resJPEGThumb",
     }
 
     VIDEO_VERSION_LOOKUP = {
-        u"original": u"resOriginal",
-        u"medium": u"resVidMed",
-        u"thumb": u"resVidSmall",
+        "original": "resOriginal",
+        "medium": "resVidMed",
+        "thumb": "resVidSmall",
     }
 
     @property
@@ -641,23 +642,23 @@ class PhotoAsset(object):
                 typed_version_lookup = self.PHOTO_VERSION_LOOKUP
 
             for key, prefix in typed_version_lookup.items():
-                if "%sRes" % prefix in self._master_record["fields"]:
+                if f"{prefix}Res" in self._master_record["fields"]:
                     fields = self._master_record["fields"]
                     version = {"filename": self.filename}
 
-                    width_entry = fields.get("%sWidth" % prefix)
+                    width_entry = fields.get(f"{prefix}Width")
                     if width_entry:
                         version["width"] = width_entry["value"]
                     else:
                         version["width"] = None
 
-                    height_entry = fields.get("%sHeight" % prefix)
+                    height_entry = fields.get(f"{prefix}Height")
                     if height_entry:
                         version["height"] = height_entry["value"]
                     else:
                         version["height"] = None
 
-                    size_entry = fields.get("%sRes" % prefix)
+                    size_entry = fields.get(f"{prefix}Res")
                     if size_entry:
                         version["size"] = size_entry["value"]["size"]
                         version["url"] = size_entry["value"]["downloadURL"]
@@ -665,7 +666,7 @@ class PhotoAsset(object):
                         version["size"] = None
                         version["url"] = None
 
-                    type_entry = fields.get("%sFileType" % prefix)
+                    type_entry = fields.get(f"{prefix}FileType")
                     if type_entry:
                         version["type"] = type_entry["value"]
                     else:
@@ -690,7 +691,7 @@ class PhotoAsset(object):
             '{"query":{"recordType":"CheckIndexingState"},'
             '"zoneID":{"zoneName":"PrimarySync"}}'
         )
-
+        # pylint: disable=consider-using-f-string
         json_data = (
             '{"operations":[{'
             '"operationType":"update",'
@@ -712,11 +713,11 @@ class PhotoAsset(object):
 
         endpoint = self._service.service_endpoint
         params = urlencode(self._service.params)
-        url = "%s/records/modify?%s" % (endpoint, params)
+        url = f"{endpoint}/records/modify?{params}"
 
         return self._service.session.post(
             url, data=json_data, headers={"Content-type": "text/plain"}
         )
 
     def __repr__(self):
-        return "<%s: id=%s>" % (type(self).__name__, self.id)
+        return f"<{type(self).__name__}: id={self.id}>"
